pub struct PointerIdentity<P: Pointer>(pub P);Expand description
Wrapper type that uses the pointer address rather than the value as the identity for the
PartialEq, Eq, PartialOrd, Ord and Hash traits.
This wrapper is transparent thanks to implementing both Deref and DerefMut, so you can
use an instance of this just like you would use an instance of the type you are wrapping.
Tuple Fields
0: PImplementations